@@ -26,8 +26,8 @@ def getIndexHtml(news_source, links):
 
 	soup = BeautifulSoup(index_html, 'html.parser')
 	content_list = soup.find('p')
-	for name in links:
-		item = '<a href="%s.html">%s</a>' % (name, name)
+	for name, fn in links:
+		item = '<a href="%s.html">%s</a>' % (fn, name)
 		content_list.append(BeautifulSoup(item, 'html.parser'))
 		content_list.append(BeautifulSoup('<br/><br/>', 'html.parser'))
 	return str(soup)
\ No newline at end of file
